@@ -2,11 +2,13 @@
 #' @title Data exchange with running Microsoft Excel instance.
 #'   
 #' @description 
-#' \code{xl}, \code{xlc}, \code{xlr}, \code{xlrc} objects are
-#' already defined in the package. It doesn't need to create or init them. Just
-#' after attaching package one can write something like this: \code{xl[a1] =
-#' "Hello, world!"} and this text should appears in \code{A1} cell on active
-#' sheet of active Excel workbook.
+#' \code{xl}, \code{xlc}, \code{xlr}, \code{xlrc} objects are already defined in
+#' the package. It doesn't need to create or init them. Just after attaching
+#' package one can write something like this: \code{xl[a1] = "Hello, world!"}
+#' and this text should appears in \code{A1} cell on active sheet of active
+#' Excel workbook. \code{xl(*)n} family of functions creates new worksheet for
+#' output. You can provide sheet name and position via
+#' \code{xl.sheet.name}/\code{before}.
 #' 
 #' @param x One of \code{xl}, \code{xlc}, \code{xlr}, \code{xlrc} objects. 
 #'   \code{xl} - read/write with/without column and row names, "r" - with 
@@ -26,7 +28,11 @@
 #'   range only if it is object of length 1. In other cases size of excel range 
 #'   is ignored - all data will be placed in Excel sheet starting from top-left 
 #'   cell of submitted range.
-#'   
+#' @param xl.sheet.name character. sheet name in active workbook (for \code{xl(*)n}).
+#' @param before character/numeric. sheet name or sheet number in active
+#'   workbook before which new sheet will be added (for \code{xl(*)n}).
+#' @param ... additional parameters. Not yet used.  
+#'
 #' @details \code{xl} object represents Microsoft Excel application. For 
 #'   convenient interactive usage arguments can be given without quotes in most 
 #'   cases (e. g. \code{xl[a1] = 5} or \code{xl[u2:u85] = "Hi"} or 
@@ -43,7 +49,7 @@
 #'   All these functions never coerce characters to factors
 #'   
 #' @return Returns appropriate dataset from Excel. 
-#' @aliases xl xlrc xlc xlr
+#' @aliases xl xlrc xlc xlr xln xlrcn xlcn xlrn
 #' @seealso
 #' \code{\link{cr}}, \code{\link{xl.current.region}}, 
 #'   
@@ -64,14 +70,14 @@
 #' 
 #' }
 #' @export
-'[.xl' = function(x,str.rng,drop = !(has.rownames(x) | has.colnames(x)),na = "")
+'[.xl' = function(x,str.rng,drop = !(has.rownames(x) | has.colnames(x)),na = "", ...)
     ### return range from Microsoft Excel. range.name is character string in form of standard
     ### Excel reference, quotes can be omitted, e. g. [A1:B5], [Sheet1!F8], [[Book3]Sheet7!B1] or range name 
     ### Function is intended to use in interactive environement 
 {
     # str.rng = as.character(sys.call())[3]
     str.rng = as.character(as.expression(substitute(str.rng)))
-    x[[str.rng,drop = drop,na = na]]
+    x[[str.rng,drop = drop,na = na, ...]]
 }
 
 
@@ -96,7 +102,6 @@ xlc = xl
 #' @export
 xlr = xl
 
-
 has.rownames(xl) = FALSE 
 has.colnames(xl) = FALSE 
 
@@ -109,17 +114,47 @@ has.colnames(xlr) = FALSE
 has.rownames(xlrc) = TRUE 
 has.colnames(xlrc) = TRUE 
 
+#######
+
+#### with new sheet ###########
+
+#' @export
+xln = xl
+
+class(xln) = c('xln',class(xl))
+
+#' @export
+xlrcn = xln
+
+#' @export
+xlcn = xln
+
+#' @export
+xlrn = xln
+
+has.rownames(xln) = FALSE 
+has.colnames(xln) = FALSE 
+
+has.rownames(xlcn) = FALSE 
+has.colnames(xlcn) = TRUE 
+
+has.rownames(xlrn) = TRUE 
+has.colnames(xlrn) = FALSE 
+
+has.rownames(xlrcn) = TRUE 
+has.colnames(xlrcn) = TRUE 
+
 
 #' @export
 #' @rdname xl
-'[[.xl' = function(x,str.rng,drop = !(has.rownames(x) | has.colnames(x)),na = "")
+'[[.xl' = function(x,str.rng,drop = !(has.rownames(x) | has.colnames(x)),na = "", ...)
     ### return range from Microsoft Excel. range.name is character string in form of standard
     ### Excel reference, e. g. ['A1:B5'], ['Sheet1!F8'], ['[Book3]Sheet7!B1'] or range name 
     ### The difference with '[' is that value should be quoted string. It's intended to use in user define functions
     ### or in cases where value is string variable with Excel range 
 {
     xl.rng = x()$Range(str.rng)
-    xl.read.range(xl.rng,drop = drop,row.names = has.rownames(x),col.names = has.colnames(x),na = na)
+    xl.read.range(xl.rng,drop = drop,row.names = has.rownames(x),col.names = has.colnames(x),na = na, ...)
 }
 
 #' @export
@@ -136,10 +171,10 @@ has.colnames(xlrc) = TRUE
 
 #' @export
 #' @rdname xl
-'[[<-.xl' = function(x,str.rng,na = "",value)
+'[[<-.xl' = function(x,str.rng,na = "", ..., value)
 {
     xl.rng = x()$Range(str.rng)
-    xl.write(value,xl.rng,row.names = has.rownames(x),col.names = has.colnames(x),na = na)
+    xl.write(value,xl.rng,row.names = has.rownames(x),col.names = has.colnames(x),na = na, ...)
     x
 }
 
@@ -154,25 +189,59 @@ has.colnames(xlrc) = TRUE
 
 #' @export
 #' @rdname xl
-'[<-.xl' = function(x,str.rng,na = "",value)
+'[<-.xl' = function(x,str.rng,na = "", ..., value)
 {
     str.rng = as.character(as.expression(substitute(str.rng)))
-    x[[str.rng,na = na]] = value
+    x[[str.rng,na = na, ...]] = value
+    x
+}
+
+#### with new worksheet ###############
+
+#' @export
+#' @rdname xl
+'[[<-.xln' = function(x,str.rng,na = "", xl.sheet.name = NULL, before = NULL, ..., value)
+{
+    xl.sheet.add(xl.sheet.name = xl.sheet.name, before = before)
+    xl.rng = x()$Range(str.rng)
+    xl.write(value,xl.rng,row.names = has.rownames(x),col.names = has.colnames(x),na = na, ...)
+    x
+}
+
+
+#' @export
+#' @rdname xl
+'$<-.xln' = function(x,str.rng,value)
+{
+    xl.sheet.add()
+    x[[str.rng]] = value
     x
 }
 
 #' @export
 #' @rdname xl
-xl.selection = function(drop = TRUE,na = "",row.names = FALSE,col.names = FALSE)
+'[<-.xln' = function(x,str.rng,na = "", xl.sheet.name = NULL, before = NULL, ..., value)
+{
+    str.rng = as.character(as.expression(substitute(str.rng)))
+    x[[str.rng,na = na, xl.sheet.name = xl.sheet.name, before = before,  ...]] = value
+    x
+}
+
+
+#################################
+
+#' @export
+#' @rdname xl
+xl.selection = function(drop = TRUE,na = "", row.names = FALSE, col.names = FALSE, ...)
     # return current selection from Microsoft Excel
 {
     ex = xl.get.excel()
     xl.rng = ex[['Selection']]
-    xl.read.range(xl.rng,drop = drop,na = na,row.names = row.names,col.names = col.names)
+    xl.read.range(xl.rng,drop = drop,na = na,row.names = row.names,col.names = col.names, ...)
 }
 
 
-xl.read.range = function(xl.rng,drop = TRUE,row.names = FALSE,col.names = FALSE,na = "")
+xl.read.range = function(xl.rng,drop = TRUE,row.names = FALSE,col.names = FALSE,na = "", ...)
     # return matrix/data.frame/vector from excel from given range
 {
     if (col.names && (xl.rng[["rows"]][["count"]]<2)) col.names = FALSE
